HistorizedStatefulValuable<T> class abstract interface

Implemented types
Implementers
Available extensions

Constructors

HistorizedStatefulValuable(StatefulValuable<T> valuable)
factory

Properties

evaluateWithContext bool
no setterinherited
first ↔ E

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns the first element.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
history UnmodifiableQueueView<ValuableHistoryNode<T>>
History of this Valuable
no setterinherited
isDisposed bool
Returns if this Object is already disposed
no setterinherited
isEmpty bool

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns true if there are no elements in this collection.
no setter
isMounted bool
Returns if this object is still mounted
no setterinherited
isNotEmpty bool

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns true if there is at least one element in this collection.
no setter
last ↔ E

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns the last element.
getter/setter pair
length int

Available on Valuable<List<E>>, provided by the ListOperators extension

The number of objects in this list.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E

Available on Valuable<List<E>>, provided by the ListOperators extension

Checks that this iterable has only one element, and returns that element.
no setter
state → T
no setterinherited
valuableContext ValuableContext?
no setterinherited

Methods

add(num other) → void

Available on StatefulValuable<T>, provided by the NumStateOperations extension

Reassign the state value by adding another number
add(E value) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Adds value to the end of this list, extending the length by one.
addAll(Iterable<E> iterable) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Appends all objects of iterable to the end of this list.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
asMap() Map<int, E>

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns an unmodifiable Map view of this.
cleanWatched() → void
inherited
clear() → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Removes all objects from this list; the length of the list becomes zero.
decrement() → void

Available on StatefulValuable<int>, provided by the IntStateOperations extension

Reassign the state by substract 1
dispose() → void
Should be called to clean all links to other Valuables, and all the rest
inherited
divide(num other) → void

Available on StatefulValuable<double>, provided by the DoubleStateOperations extension

Reassign the state value by dividing with an other number
divide(num other) → void

Available on StatefulValuable<int>, provided by the IntStateOperations extension

Reassign the state value by dividing with an other number
equals(dynamic other, {ValuableScope? scope}) Valuable<bool>

Available on Valuable<Output>, provided by the ValuableScopeHelpers extension

Compare with a value that type is Output or another Valuable
getValue([ValuableContext? context]) → T
Get the current value of the Valuable
inherited
getValueDefinition(bool reevaluatingNeeded, [ValuableContext? context]) → T
This method should be redefined in ever sub-classes to determine how works the method getValue
inherited
historize() HistorizedStatefulValuable<T>
Build an HistorizedStatefulValuable based on this Valuable
inherited
historizeRW() ReWritableHistorizedValuable<T>
Build an ReWritableHistorizedValuable based on this Valuable
inherited
increment() → void

Available on StatefulValuable<int>, provided by the IntStateOperations extension

Reassign the state by adding 1
insert(int index, E element) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Inserts the object at position index in this list.
insertAll(int index, Iterable<E> iterable) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Inserts all objects of iterable at position index in this list.
listenDispose(VoidCallback onDispose) VoidCallback
Allows to be notified when this Valuable is disposed
inherited
listUpdated() → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Notify listener that the list or its values have been updated
map<Other>(Other toElement(Output), {ValuableScope? scope}) Valuable<Other>

Available on Valuable<Output>, provided by the ValuableScopeHelpers extension

A method to map a Valuable from Output to Other
markToReevaluate() → void
Mark the valuable to be reevaluated
inherited
multiply(num other) → void

Available on StatefulValuable<T>, provided by the NumStateOperations extension

Reassign the state value by multiplying with another number
negate() → void

Available on StatefulValuable<bool>, provided by the BoolStateOperations extension

Reassign the state value with the negated current value (true -> false)
negate() → void

Available on StatefulValuable<T>, provided by the NumStateOperations extension

Reassign the state value with the negated current value (current * -1)
negation({ValuableScope? scope}) Valuable<bool>

Available on Valuable<bool>, provided by the BoolOperators extension

Create a new Valuable<bool> that depends on the current, but with the negated value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(dynamic other, {ValuableScope? scope}) Valuable<bool>

Available on Valuable<Output>, provided by the ValuableScopeHelpers extension

Compare with a value that type is Output or another Valuable
notifyListeners() → void
Call all the registered listeners.
inherited
onValuableChange() → void
Called when a Valuable notify a change.
inherited
onWatchedValuableDispose(Valuable _) → void
Allows inheriting classes to react when a watched Valuable is disposed.
inherited
remove(Object? value) bool

Available on Valuable<List<E>>, provided by the ListOperators extension

Removes the first occurrence of value from this list.
removeAt(int index) → E

Available on Valuable<List<E>>, provided by the ListOperators extension

Removes the object at position index from this list.
removeLast() → E

Available on Valuable<List<E>>, provided by the ListOperators extension

Pops and returns the last object in this list.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(E element)) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Removes all objects from this list that satisfy test.
retainWhere(bool test(E element)) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Removes all objects from this list that fail to satisfy test.
setValue(T value) → void
inherited
shuffle([Random? random]) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Shuffles the elements of this list randomly.
sort([int compare(E a, E b)?]) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Sorts this list according to the order specified by the compare function.
substract(num other) → void

Available on StatefulValuable<T>, provided by the NumStateOperations extension

Deprecated misspelling of subtract; forwards to subtract.
subtract(num other) → void

Available on StatefulValuable<T>, provided by the NumStateOperations extension

Reassign the state value by subtracting another number
then<Output>(Valuable<Output> value, {required Valuable<Output> elseValue, ValuableScope? scope}) Valuable<Output>

Available on Valuable<bool>, provided by the BoolOperators extension

Get a new Valuable whose value depends on the current Valuable value.
thenValue<Output>(Output value, {required Output elseValue, ValuableScope? scope}) Valuable<Output>

Available on Valuable<bool>, provided by the BoolOperators extension

Same as then function, but with direct value as parameters
toComputedValuable<T>(T computation(L listenable), [ValuableScope? scope]) Valuable<T>

Available on L, provided by the ListenableValuable extension

Method to transform a ValueListenable to a Valuable
toFutureAsyncValue({ValuableScope? scope}) Valuable<ValuableAsyncValue<T>>

Available on Valuable<Future<T>>, provided by the ValuableFutureExtension extension

toStreamAsyncValue({ValuableScope? scope}) Valuable<ValuableAsyncValue<T>>

Available on Valuable<Stream<T>>, provided by the ValuableStreamExtension extension

toString() String
A string representation of this object.
inherited
watch<T>(Valuable<T> valuable, {ValuableContext? valuableContext, ValuableWatcherSelector<T>? selector}) → T
Watch a valuable, that eventually change
inherited
watchIt(BuildContext context, {ValuableWatcherSelector<T>? selector}) → T

Available on Valuable<T>, provided by the WidgetValuable extension

Operators

operator %(Valuable<num> other) Valuable<num>

Available on Valuable<T>, provided by the NumOperators extension

Euclidean modulo operator.
operator &(Valuable<bool> other) Valuable<bool>

Available on Valuable<bool>, provided by the BoolOperators extension

Logical AND between Valuable/boolean value
operator *(Valuable<num> other) Valuable<num>

Available on Valuable<T>, provided by the NumOperators extension

Multiplication operator.
operator +(List<E> other) List<E>

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns the concatenation of this list and other.
operator +(Valuable<num> other) Valuable<num>

Available on Valuable<T>, provided by the NumOperators extension

Addition operator.
operator +(Valuable<String> other) Valuable<String>

Available on Valuable<String>, provided by the StringOperators extension

Concate operator
operator -(Valuable<num> other) Valuable<num>

Available on Valuable<T>, provided by the NumOperators extension

Subtraction operator.
operator /(Valuable<num> other) Valuable<double>

Available on Valuable<T>, provided by the NumOperators extension

Division operator.
operator <(dynamic other) Valuable<bool>
Compare with a value that type is Output or another Valuable
inherited
operator <=(dynamic other) Valuable<bool>
Compare with a value that type is Output or another Valuable
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(dynamic other) Valuable<bool>
Compare with a value that type is Output or another Valuable
inherited
operator >=(dynamic other) Valuable<bool>
Compare with a value that type is Output or another Valuable
inherited
operator [](int index) → E

Available on Valuable<List<E>>, provided by the ListOperators extension

Returns the object at the given index in the list or throws a RangeError if index is out of bounds.
operator []=(int index, E value) → void

Available on Valuable<List<E>>, provided by the ListOperators extension

Sets the value at the given index in the list to value or throws a RangeError if index is out of bounds.
operator unary-() Valuable<num>

Available on Valuable<T>, provided by the NumOperators extension

Negate operator.
operator |(Valuable<bool> other) Valuable<bool>

Available on Valuable<bool>, provided by the BoolOperators extension

Logical OR between Valuable/boolean value
operator ~/(Valuable<num> other) Valuable<int>

Available on Valuable<T>, provided by the NumOperators extension

Truncating division operator.