operator <= method
Compare with a value that type is Output or another Valuable
If other type is not Output or Valuable then an UnmatchTypeValuableError
is thrown
Implementation
Valuable<bool> operator <=(dynamic other) {
return _getCompare(other, CompareOperator.smallerOrEquals);
}