valuable library
Classes
-
FutureValuable<
Output, Res> - A Valuable that depends on a Future
-
HistorizedStatefulValuable<
T> -
HistorizedValuable<
T> - Contract class for Valuable that can maintain an history
-
HistorizedValuableLinker<
T> -
None<
T> -
Opt<
T> -
ReWritableHistorizedValuable<
T> - Contract class for StatefulValuable that provide rewritable history management
-
Some<
T> -
StatefulValuable<
Output> - A Valuable that manage a state.
-
StreamValuable<
Output, Msg> - A Valuable that remains on a Stream<Msg>
-
UnmodifiableQueueView<
E> -
Valuable<
Output> - Main class Valuable
-
ValuableAsyncData<
T> - Representation of a valid data provided by an async process (Future, Stream, ...)
-
ValuableAsyncError<
T> - Representation of an error that occured during an async process
-
ValuableAsyncNoData<
T> - Representation of a momentum when no data is provided, and no error occured
-
ValuableAsyncValue<
T> - Provide a safe representation of an async value
- ValuableBoolGroup
- A class to make logical operations with Valuable<bool>
- ValuableCallback
- User-defined callback that can watch Valuable to be automatically re-call
-
ValuableCaseItem<
Switch, Output> -
ValuableCompare<
T> - A class to map Valuables comparison to a Valuable<bool>
- ValuableConsumer
- A widget that is used to watch Valuable inside a widget tree
- ValuableContext
- Immutable object that let transit informations about the current context of a valuable's value reading
- ValuableDebugSession
-
ValuableHistoryNode<
T> - Valuable value representation at a certain momentum
-
ValuableIf<
Output> -
ValuableLinker<
Output> - A special Valuable that can link to another Valuable to provide a value
-
ValuableNumOperation<
Output extends num> - Class to do calculus with numeric operands, and obtain a Valuable<num>.
- ValuableScope
- A class to manage the lifecycle of multiple valuables and callbacks, and dispose them all together when needed
- ValuableStringOperation
- Operations for String
-
ValuableSwitch<
Switch, Output> - ValuableWidget
- ValuableWidgetElement
- VDisposable
- VDisposableMixin
Enums
- CompareOperator
- Comparison operator
- NumOperator
- Calculus operators for num operands
- StringOperator
- Possible operations between Valuable<String>
Mixins
-
StatefulValuableMixin<
Output> - Provide some method implementations to fullfil StatefulValuable contract
-
StateValuableScopeMixin<
T extends StatefulWidget> - A mixin to provide a scope for Valuables, allowing to easily manage their lifecycle
-
ValuableLinkerMixin<
Output> - Provide some method implementations to fullfil ValuableLinker contract
- ValuableWatcherMixin
- A mixin to provide extension of classes that might want to watch some valuable and take action on possible changes
Extensions
-
BoolOperators
on Valuable<
bool> -
BoolStateOperations
on StatefulValuable<
bool> - Available operations on StatefulValuable<bool>
-
DoubleStateOperations
on StatefulValuable<
double> - Available operations on StatefulValuable<double>
-
FutureExtension
on Future<
T> -
IntStateOperations
on StatefulValuable<
int> - Available operations on StatefulValuable<int>
- ListenableValuable on L
- Method to transform a ValueListenable to a Valuable
-
ListOperators
on Valuable<
List< E> > -
NumOperators
on Valuable<
T> -
Extension to define operators for Valuable where
T extends num -
NumStateOperations
on StatefulValuable<
T> - Available operations on StatefulValuable<T extends num>
-
StreamExtension
on Stream<
T> -
StringOperators
on Valuable<
String> - Extension to define operators for Valuable<String>
-
ValuableFutureExtension
on Valuable<
Future< T> > -
ValuableScopeHelpers
on Valuable<
Output> - Extension providing scope-aware helpers for Valuable
-
ValuableStreamExtension
on Valuable<
Stream< T> > - ValuableWatcherExtension on ValuableWatcher
- Provide extension on ValuableWatcher
-
ValueListenableValuable
on ValueListenable<
T> - Method to transform a ValueListenable to a Valuable
-
WidgetValuable
on Valuable<
T>
Properties
-
boolFalse
→ Valuable<
bool> -
Shortcut to get a valuable with the value false
final
-
boolTrue
→ Valuable<
bool> -
Shortcut to get a valuable with the value true
final
-
doubleZero
→ Valuable<
double> -
Shortcut to get a valuable with the double value 0.0
final
-
intZero
→ Valuable<
int> -
Shortcut to get a valuable with the int value 0
final
-
stringEmpty
→ Valuable<
String> -
Shortcut to get a valuable with the value of an empty string
final
Typedefs
-
FutureValuableAsyncValue<
Res> = FutureValuable< ValuableAsyncValue< Res> , Res> - Equivalent to a FutureValuable<ValuableAsyncValue<Res>, Res>
-
StreamValuableAsyncValue<
Res> = StreamValuable< ValuableAsyncValue< Res> , Res> - Equivalent to a StreamValuable<ValuableAsyncValue<Res>, Res>
- ValuableCallbackPrototype = void Function(ValuableWatcher watch, {ValuableContext? valuableContext})
- ValuableConsumerBuilder = Widget Function(BuildContext context, ValuableWatcher watch, Widget? child)
- Contract for the implementation function needed to build Widget for a ValuableConsumer
-
ValuableGetFutureError<
Output> = Output Function(ValuableContext? context, Object error, StackTrace stackTrace) - Method prototype for a Future error
-
ValuableGetFutureLoading<
Output> = Output Function(ValuableContext? context) - Method prototype to get a value while a Future is not complete/in error
-
ValuableGetFutureResult<
Output, Res> = Output Function(ValuableContext? context, Res result) - Method prototype for a Future complete
-
ValuableGetStreamData<
Output, Msg> = Output Function(ValuableContext? context, Msg data) - Method prototype for onData of the Stream
-
ValuableGetStreamDone<
Output> = Output Function(ValuableContext? context) - Method prototype for onDone of the Stream
-
ValuableGetStreamError<
Output> = Output Function(ValuableContext? context, Object error, StackTrace stackTrace) - Method prototype for onError of the Stream
-
ValuableParentWatcher<
T> = T Function(ValuableWatcher watch, {ValuableContext? valuableContext}) -
ValuableStatefulWidgetParam<
P, T extends StatefulWidget> = Valuable< P> Function(T widget) -
ValuableValueCleaningCallback<
T> = void Function(T previousValue, Opt< T> newValue, bool isDisposal) -
ValuableWatcher
= T Function<
T>(Valuable< T> valuable, {ValuableWatcherSelector<T> ? selector, ValuableContext? valuableContext}) -
ValuableWatcherSelector<
T> = bool Function(Valuable< T> valuable, T previousWatchedValue)
Exceptions / Errors
-
ValuableDisposedException<
T> - For case of trying to read a Valuable that is already disposed
- ValuableException
- For Valuable to have its own Exceptions
- ValuableIllegalUseException
- For case of illegal use when using Valuable