- Implemented types
- Implementers
- Available extensions
Constructors
-
HistorizedStatefulValuable(StatefulValuable<
T> valuable) -
factory
Properties
- evaluateWithContext → bool
-
no setterinherited
- first ↔ E
-
Available on Valuable<
Returns the first element.List< , provided by the ListOperators extensionE> >getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
history
→ UnmodifiableQueueView<
ValuableHistoryNode< T> > -
History of this Valuable
no setterinherited
- isDisposed → bool
-
Returns if this Object is already disposed
no setterinherited
- isEmpty → bool
-
Available on Valuable<
ReturnsList< , provided by the ListOperators extensionE> >trueif there are no elements in this collection.no setter - isMounted → bool
-
Returns if this object is still mounted
no setterinherited
- isNotEmpty → bool
-
Available on Valuable<
Returns true if there is at least one element in this collection.List< , provided by the ListOperators extensionE> >no setter - last ↔ E
-
Available on Valuable<
Returns the last element.List< , provided by the ListOperators extensionE> >getter/setter pair - length ↔ int
-
Available on Valuable<
The number of objects in this list.List< , provided by the ListOperators extensionE> >getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → E
-
Available on Valuable<
Checks that this iterable has only one element, and returns that element.List< , provided by the ListOperators extensionE> >no setter - state → T
-
no setterinherited
- valuableContext → ValuableContext?
-
no setterinherited
Methods
-
add(
num other) → void -
Available on StatefulValuable<
Reassign the state value by adding another numberT> , provided by the NumStateOperations extension -
add(
E value) → void -
Available on Valuable<
AddsList< , provided by the ListOperators extensionE> >valueto the end of this list, extending the length by one. -
addAll(
Iterable< E> iterable) → void -
Available on Valuable<
Appends all objects ofList< , provided by the ListOperators extensionE> >iterableto the end of this list. -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
asMap(
) → Map< int, E> -
Available on Valuable<
Returns an unmodifiable Map view ofList< , provided by the ListOperators extensionE> >this. -
cleanWatched(
) → void -
inherited
-
clear(
) → void -
Available on Valuable<
Removes all objects from this list; the length of the list becomes zero.List< , provided by the ListOperators extensionE> > -
decrement(
) → void -
Available on StatefulValuable<
Reassign the state by substract 1int> , provided by the IntStateOperations extension -
dispose(
) → void -
Should be called to clean all links to other Valuables, and all the rest
inherited
-
divide(
num other) → void -
Available on StatefulValuable<
Reassign the state value by dividing with an other numberdouble> , provided by the DoubleStateOperations extension -
divide(
num other) → void -
Available on StatefulValuable<
Reassign the state value by dividing with an other numberint> , provided by the IntStateOperations extension -
equals(
dynamic other, {ValuableScope? scope}) → Valuable< bool> -
Available on Valuable<
Compare with a value that type isOutput> , provided by the ValuableScopeHelpers extensionOutputor another Valuable -
getValue(
[ValuableContext? context]) → T -
Get the current value of the Valuable
inherited
-
getValueDefinition(
bool reevaluatingNeeded, [ValuableContext? context]) → T -
This method should be redefined in ever sub-classes to determine how works
the method getValue
inherited
-
historize(
) → HistorizedStatefulValuable< T> -
Build an HistorizedStatefulValuable based on this Valuable
inherited
-
historizeRW(
) → ReWritableHistorizedValuable< T> -
Build an ReWritableHistorizedValuable based on this Valuable
inherited
-
increment(
) → void -
Available on StatefulValuable<
Reassign the state by adding 1int> , provided by the IntStateOperations extension -
insert(
int index, E element) → void -
Available on Valuable<
Inserts the object at positionList< , provided by the ListOperators extensionE> >indexin this list. -
insertAll(
int index, Iterable< E> iterable) → void -
Available on Valuable<
Inserts all objects ofList< , provided by the ListOperators extensionE> >iterableat positionindexin this list. -
listenDispose(
VoidCallback onDispose) → VoidCallback -
Allows to be notified when this Valuable is disposed
inherited
-
listUpdated(
) → void -
Available on Valuable<
Notify listener that the list or its values have been updatedList< , provided by the ListOperators extensionE> > -
map<
Other> (Other toElement(Output), {ValuableScope? scope}) → Valuable< Other> -
Available on Valuable<
A method to map a Valuable fromOutput> , provided by the ValuableScopeHelpers extensionOutputtoOther -
markToReevaluate(
) → void -
Mark the valuable to be reevaluated
inherited
-
multiply(
num other) → void -
Available on StatefulValuable<
Reassign the state value by multiplying with another numberT> , provided by the NumStateOperations extension -
negate(
) → void -
Available on StatefulValuable<
Reassign the state value with the negated current value (true -> false)bool> , provided by the BoolStateOperations extension -
negate(
) → void -
Available on StatefulValuable<
Reassign the state value with the negated current value (current * -1)T> , provided by the NumStateOperations extension -
negation(
{ValuableScope? scope}) → Valuable< bool> -
Available on Valuable<
Create a new Valuable<bool> that depends on the current, but with the negated valuebool> , provided by the BoolOperators extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
dynamic other, {ValuableScope? scope}) → Valuable< bool> -
Available on Valuable<
Compare with a value that type isOutput> , provided by the ValuableScopeHelpers extensionOutputor another Valuable -
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onValuableChange(
) → void -
Called when a Valuable notify a change.
inherited
-
onWatchedValuableDispose(
Valuable _) → void -
Allows inheriting classes to react when a watched Valuable is disposed.
inherited
-
remove(
Object? value) → bool -
Available on Valuable<
Removes the first occurrence ofList< , provided by the ListOperators extensionE> >valuefrom this list. -
removeAt(
int index) → E -
Available on Valuable<
Removes the object at positionList< , provided by the ListOperators extensionE> >indexfrom this list. -
removeLast(
) → E -
Available on Valuable<
Pops and returns the last object in this list.List< , provided by the ListOperators extensionE> > -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeWhere(
bool test(E element)) → void -
Available on Valuable<
Removes all objects from this list that satisfyList< , provided by the ListOperators extensionE> >test. -
retainWhere(
bool test(E element)) → void -
Available on Valuable<
Removes all objects from this list that fail to satisfyList< , provided by the ListOperators extensionE> >test. -
setValue(
T value) → void -
inherited
-
shuffle(
[Random? random]) → void -
Available on Valuable<
Shuffles the elements of this list randomly.List< , provided by the ListOperators extensionE> > -
sort(
[int compare(E a, E b)?]) → void -
Available on Valuable<
Sorts this list according to the order specified by theList< , provided by the ListOperators extensionE> >comparefunction. -
substract(
num other) → void -
Available on StatefulValuable<
Deprecated misspelling of subtract; forwards to subtract.T> , provided by the NumStateOperations extension -
subtract(
num other) → void -
Available on StatefulValuable<
Reassign the state value by subtracting another numberT> , provided by the NumStateOperations extension -
then<
Output> (Valuable< Output> value, {required Valuable<Output> elseValue, ValuableScope? scope}) → Valuable<Output> -
Available on Valuable<
Get a new Valuable whose value depends on the current Valuable value.bool> , provided by the BoolOperators extension -
thenValue<
Output> (Output value, {required Output elseValue, ValuableScope? scope}) → Valuable< Output> -
Available on Valuable<
Same as then function, but with direct value as parametersbool> , provided by the BoolOperators extension -
toComputedValuable<
T> (T computation(L listenable), [ValuableScope? scope]) → Valuable< T> -
Available on L, provided by the ListenableValuable extension
Method to transform a ValueListenable to a Valuable -
toFutureAsyncValue(
{ValuableScope? scope}) → Valuable< ValuableAsyncValue< T> > -
Available on Valuable<
Future< , provided by the ValuableFutureExtension extensionT> > -
toStreamAsyncValue(
{ValuableScope? scope}) → Valuable< ValuableAsyncValue< T> > -
Available on Valuable<
Stream< , provided by the ValuableStreamExtension extensionT> > -
toString(
) → String -
A string representation of this object.
inherited
-
watch<
T> (Valuable< T> valuable, {ValuableContext? valuableContext, ValuableWatcherSelector<T> ? selector}) → T -
Watch a valuable, that eventually change
inherited
-
watchIt(
BuildContext context, {ValuableWatcherSelector< T> ? selector}) → T -
Available on Valuable<
T> , provided by the WidgetValuable extension
Operators
-
operator %(
Valuable< num> other) → Valuable<num> -
Available on Valuable<
Euclidean modulo operator.T> , provided by the NumOperators extension -
operator &(
Valuable< bool> other) → Valuable<bool> -
Available on Valuable<
Logical AND between Valuable/boolean valuebool> , provided by the BoolOperators extension -
operator *(
Valuable< num> other) → Valuable<num> -
Available on Valuable<
Multiplication operator.T> , provided by the NumOperators extension -
operator +(
List< E> other) → List<E> -
Available on Valuable<
Returns the concatenation of this list andList< , provided by the ListOperators extensionE> >other. -
operator +(
Valuable< num> other) → Valuable<num> -
Available on Valuable<
Addition operator.T> , provided by the NumOperators extension -
operator +(
Valuable< String> other) → Valuable<String> -
Available on Valuable<
Concate operatorString> , provided by the StringOperators extension -
operator -(
Valuable< num> other) → Valuable<num> -
Available on Valuable<
Subtraction operator.T> , provided by the NumOperators extension -
operator /(
Valuable< num> other) → Valuable<double> -
Available on Valuable<
Division operator.T> , provided by the NumOperators extension -
operator <(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator <=(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator >=(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator [](
int index) → E -
Available on Valuable<
Returns the object at the givenList< , provided by the ListOperators extensionE> >indexin the list or throws a RangeError ifindexis out of bounds. -
operator []=(
int index, E value) → void -
Available on Valuable<
Sets the value at the givenList< , provided by the ListOperators extensionE> >indexin the list tovalueor throws a RangeError ifindexis out of bounds. -
operator unary-(
) → Valuable< num> -
Available on Valuable<
Negate operator.T> , provided by the NumOperators extension -
operator |(
Valuable< bool> other) → Valuable<bool> -
Available on Valuable<
Logical OR between Valuable/boolean valuebool> , provided by the BoolOperators extension -
operator ~/(
Valuable< num> other) → Valuable<int> -
Available on Valuable<
Truncating division operator.T> , provided by the NumOperators extension