ValuableStringOperation class
Operations for String
- Inheritance
-
- Object
- ChangeNotifier
- Valuable<
String> - ValuableStringOperation
- Available extensions
Constructors
-
ValuableStringOperation(Valuable<
String> operand1, StringOperator operator, Valuable<String> operand2) -
ValuableStringOperation.concate(Valuable<
String> operand1, Valuable<String> operand2) - Sum operation
Properties
- evaluateWithContext → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDisposed → bool
-
Returns if this Object is already disposed
no setterinherited
- isMounted → bool
-
Returns if this object is still mounted
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valuableContext → ValuableContext?
-
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
cleanWatched(
) → void -
inherited
-
dispose(
) → void -
Should be called to clean all links to other Valuables, and all the rest
inherited
-
getValue(
[ValuableContext? context]) → String -
Get the current value of the Valuable
inherited
-
getValueDefinition(
bool reevaluatingNeeded, [ValuableContext? context]) → String -
This method should be redefined in ever sub-classes to determine how works
the method getValue
override
-
historize(
) → HistorizedValuable< String> -
Build an HistorizedValuable based on this Valuable
inherited
-
listenDispose(
VoidCallback onDispose) → VoidCallback -
Allows to be notified when this Valuable is disposed
inherited
-
markToReevaluate(
) → void -
Mark the valuable to be reevaluated
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onValuableChange(
) → void -
Called when a Valuable notify a change.
inherited
-
onWatchedValuableDispose(
Valuable _) → void -
Allows inheriting classes to react when a watched Valuable is disposed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toComputedValuable<
T> (T computation(L listenable), [ValuableScope? scope]) → Valuable< T> -
Available on L, provided by the ListenableValuable extension
Method to transform a ValueListenable to a Valuable -
toString(
) → String -
A string representation of this object.
inherited
-
watch<
T> (Valuable< T> valuable, {ValuableContext? valuableContext, ValuableWatcherSelector<T> ? selector}) → T -
Watch a valuable, that eventually change
inherited
Operators
-
operator +(
Valuable< String> other) → Valuable<String> -
Available on Valuable<
Concate operatorString> , provided by the StringOperators extension -
operator <(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator <=(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited -
operator >=(
dynamic other) → Valuable< bool> -
Compare with a value that type is
Outputor another Valuableinherited